@@ -33,9 +33,6 @@
 #define DEFAULT_PIDFILE HA_VARRUNDIR "storage_mon.pid"
 #define DEFAULT_ATTRNAME "#health-storage_mon"
 #define SMON_GET_RESULT_COMMAND "get_check_value"
-#define SMON_RESULT_OK "green"
-#define SMON_RESULT_NG "red"
-#define SMON_RESULT_COMMAND_ERROR "unknown command"
 #define SMON_BUFF_1MEG 1048576
 #define SMON_MAX_IPCSNAME 256
 #define SMON_MAX_MSGSIZE 128
@@ -122,6 +119,8 @@ static void *test_device(const char *device, int verbose, int inject_error_perce
 	int device_fd;
 	int res;
 	off_t seek_spot;
+	int sec_size = 512;
+	void *buffer;
 
 	if (verbose) {
 		printf("Testing device %s\n", device);
@@ -153,23 +152,7 @@ static void *test_device(const char *device, int verbose, int inject_error_perce
 		PRINT_STORAGE_MON_INFO("%s: opened %s O_DIRECT, size=%zu", device, (flags & O_DIRECT)?"with":"without", devsize);
 	}
 
-	/* Don't fret about real randomness */
-	srand(time(NULL) + getpid());
-	/* Pick a random place on the device - sector aligned */
-	seek_spot = (rand() % (devsize-1024)) & 0xFFFFFFFFFFFFFE00;
-	res = lseek(device_fd, seek_spot, SEEK_SET);
-	if (res < 0) {
-		PRINT_STORAGE_MON_ERR("Failed to seek %s: %s", device, strerror(errno));
-		goto error;
-	}
-	if (verbose) {
-		PRINT_STORAGE_MON_INFO("%s: reading from pos %ld", device, seek_spot);
-	}
-
 	if (flags & O_DIRECT) {
-		int sec_size = 0;
-		void *buffer;
-
 #ifdef __FreeBSD__
 		res = ioctl(device_fd, DIOCGSECTORSIZE, &sec_size);
 #else
@@ -179,33 +162,34 @@ static void *test_device(const char *device, int verbose, int inject_error_perce
 			PRINT_STORAGE_MON_ERR("Failed to get block device sector size for %s: %s", device, strerror(errno));
 			goto error;
 		}
+	}
 
-		if (posix_memalign(&buffer, sysconf(_SC_PAGESIZE), sec_size) != 0) {
-			PRINT_STORAGE_MON_ERR("Failed to allocate aligned memory: %s", strerror(errno));
-			goto error;
-		}
-		res = read(device_fd, buffer, sec_size);
-		free(buffer);
-		if (res < 0) {
-			PRINT_STORAGE_MON_ERR("Failed to read %s: %s", device, strerror(errno));
-			goto error;
-		}
-		if (res < sec_size) {
-			PRINT_STORAGE_MON_ERR("Failed to read %d bytes from %s, got %d", sec_size, device, res);
-			goto error;
-		}
-	} else {
-		char buffer[512];
+	/* Don't fret about real randomness */
+	srand(time(NULL) + getpid());
+	/* Pick a random place on the device - sector aligned */
+	seek_spot = (rand() % (devsize-sec_size)) & ~(((off_t) sec_size)-1);
+	res = lseek(device_fd, seek_spot, SEEK_SET);
+	if (res < 0) {
+		PRINT_STORAGE_MON_ERR("Failed to seek %s: %s", device, strerror(errno));
+		goto error;
+	}
+	if (verbose) {
+		PRINT_STORAGE_MON_INFO("%s: reading from pos %ld", device, seek_spot);
+	}
 
-		res = read(device_fd, buffer, sizeof(buffer));
-		if (res < 0) {
-			PRINT_STORAGE_MON_ERR("Failed to read %s: %s", device, strerror(errno));
-			goto error;
-		}
-		if (res < (int)sizeof(buffer)) {
-			PRINT_STORAGE_MON_ERR("Failed to read %ld bytes from %s, got %d", sizeof(buffer), device, res);
-			goto error;
-		}
+	if (posix_memalign(&buffer, sysconf(_SC_PAGESIZE), sec_size) != 0) {
+		PRINT_STORAGE_MON_ERR("Failed to allocate aligned memory: %s", strerror(errno));
+		goto error;
+	}
+	res = read(device_fd, buffer, sec_size);
+	free(buffer);
+	if (res < 0) {
+		PRINT_STORAGE_MON_ERR("Failed to read %s: %s", device, strerror(errno));
+		goto error;
+	}
+	if (res < sec_size) {
+		PRINT_STORAGE_MON_ERR("Failed to read %d bytes from %s, got %d", sec_size, device, res);
+		goto error;
 	}
 
 	/* Fake an error */
@@ -323,7 +307,14 @@ static int32_t sigchld_handler(int32_t sig, void *data)
 
 						finished_count++;
 						test_forks[index] = 0;
-					
+
+						/* Update the result value for the client response once all checks have completed. */
+						if (device_count == finished_count) { 
+							response_final_score = final_score;
+							if (!daemon_check_first_all_devices) {
+								daemon_check_first_all_devices = TRUE;
+							}
+						}
 					}
 				}
 			} else {
@@ -444,15 +435,7 @@ static int test_device_main(gpointer data)
 		if (is_child_runnning()) {
 			device_check = FALSE;
 		}
-		
-		if (device_count == finished_count && device_check) { 
-			/* Update the result value for the client response once all checks have completed. */
-			response_final_score = final_score;
 
-			if (!daemon_check_first_all_devices) {
-				daemon_check_first_all_devices = TRUE;
-			}
-		}
 	}
 
 	if (device_check) {
